import React from 'react';
import Loadable from 'react-loadable';
import Header from 'components/header/Header';
import Content from 'components/content/Content';
import Navigator from 'components/navigator/Navigator';
import View from 'components/view/View';
import Footer from 'components/footer/Footer';
import LoadingView from 'components/loading/LoadingView';
import withStyles from 'isomorphic-style-loader/lib/withStyles';
import style from 'components/App.scss';
import { Switch, Route, Link } from 'react-router-dom';

const LoadableDashboard = Loadable({
  loader: () => import('components/dashboard/Dashboard'),
  loading: LoadingView,
});

const LoadableSettings = Loadable({
  loader: () => import('components/settings/Settings'),
  loading: LoadingView,
});

/**
 * The main React-application starts from here.
 */
const App = () => (
  <div className="App">
    <Header />
    <Content>
      <Navigator>
        <Link to="/dashboard">Go to dashboard</Link>
        <Link to="/settings">Go to settings</Link>
      </Navigator>
      <View>
        <Switch>
          <Route exact path="/dashboard" component={LoadableDashboard} />
          <Route exact path="/settings" component={LoadableSettings} />
        </Switch>
      </View>
    </Content>
    <Footer />
  </div>
);

export default withStyles(style)(App);
